Run BioKEEN
===========
Configure an experiment through the CLI and train and evaluate a model
----------------------------------------------------------------------
To get an overview of the available commands in BioKEEN, please run:

.. code-block:: sh

   biokeen

Step 1: Start CLI
~~~~~~~~~~~~~~~~~
.. code-block:: sh

   biokeen start

Step 2: Provide the dataset
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. image:: ../images/provide_dataset.png

Step 3: Specify execution mode
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/execution_mode.png

Step 4: Select KGE model
~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/select_model.png

Step 5: Specify model dependent hyper-parameters
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Step 6: Specify the batch-size
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/batch_size.png

Step 7: Specify the number of training epochs
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/epochs.png

Step 8: Specify whether to evaluate the model
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/epochs.png

Step 9: Specify whether to evaluate the model
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/epochs.png

Step 10: Provide a random seed
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/random_seed.png

Step 12: Specify preferred device
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/random_seed.png

Step 13: Specify the path to the output directory
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: ../images/output_directory.png
